==> open-xchange-guard_2.4.2.orig.tar.bz2: open-xchange-guard-2.4.2/com.openexchange.guard.pgpcore.services/src/com/openexchange/guard/pgpcore/services/exceptions/PGPCoreServicesExceptionCodes.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.pgpcore.services.exceptions;

import com.openexchange.exception.Category;
import com.openexchange.exception.DisplayableOXExceptionCode;
import com.openexchange.exception.OXException;
import com.openexchange.exception.OXExceptionFactory;
import com.openexchange.exception.OXExceptionStrings;
import com.openexchange.guard.exceptions.GuardAuthExceptionMessages;


/**
 * {@link PGPCoreServicesExceptionCodes}
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.4.2
 */
public enum PGPCoreServicesExceptionCodes implements DisplayableOXExceptionCode {

    RECIPIENT_KEY_NOT_FOUND("Unable to retrieve recipient's key (%1$s)",PGPCoreServicesExceptionMessages.RECIPIENT_KEY_NOT_FOUND, Category.CATEGORY_ERROR, 1),
    SIGNING_KEY_NOT_FOUND("Unable to retrieve signing key (%1$s)", PGPCoreServicesExceptionMessages.SIGNING_KEY_NOT_FOUND, Category.CATEGORY_ERROR, 2),
    ENCRYPTION_ERROR("An PGP encryption error occured: %1$s", PGPCoreServicesExceptionMessages.ENCRYPTION_ERROR, Category.CATEGORY_ERROR,3),
    DECRYPTION_ERROR("An PGP decryption error occured: %1$s", PGPCoreServicesExceptionMessages.DECRYPTION_ERROR, Category.CATEGORY_ERROR,4),
    SIGNING_ERROR("An PGP signing error occured: %1$s", PGPCoreServicesExceptionMessages.SIGNING_ERROR,Category.CATEGORY_ERROR,5), 
    SIGNATURE_VERIFICATION_ERROR("An PGP signature verification error occured: %1$s",PGPCoreServicesExceptionMessages.SIGNATURE_VERIFICATION_ERROR, Category.CATEGORY_ERROR,6),
    BAD_PASSWORD("Bad password.", GuardAuthExceptionMessages.BAD_PASSWORD_MSG, CATEGORY_USER_INPUT, 7),
    UNEXPECTED_ERROR("Unexpected error occured: %1$s", PGPCoreServicesExceptionMessages.UNEXPECTED_ERROR, CATEGORY_ERROR,8)
    
    ;

    private final String message;
    private final String displayMessage;
    private final Category category;
    private final int number;

    private PGPCoreServicesExceptionCodes(String message, Category category, int number) {
        this(message, null, category, number);
    }

    private PGPCoreServicesExceptionCodes(String message, String displayMessage, Category category, int number) {
        this.message = message;
        this.displayMessage = displayMessage != null ? displayMessage : OXExceptionStrings.MESSAGE;
        this.category = category;
        this.number = number;
    }

    @Override
    public String getPrefix() {
        return "GRD-SVS";
    }

    @Override
    public int getNumber() {
        return number;
    }

    @Override
    public String getMessage() {
        return message;
    }

    @Override
    public String getDisplayMessage() {
        return displayMessage;
    }

    @Override
    public Category getCategory() {
        return category;
    }

    @Override
    public boolean equals(OXException e) {
        return OXExceptionFactory.getInstance().equals(this, e);
    }

    /**
     * Creates a new {@link OXException} instance pre-filled with this code's attributes.
     *
     * @return The newly created {@link OXException} instance
     */
    public OXException create() {
        return OXExceptionFactory.getInstance().create(this, new Object[0]);
    }

    /**
     * Creates a new {@link OXException} instance pre-filled with this code's attributes.
     *
     * @param args The message arguments in case of printf-style message
     * @return The newly created {@link OXException} instance
     */
    public OXException create(Object... args) {
        return OXExceptionFactory.getInstance().create(this, (Throwable) null, args);
    }

    /**
     * Creates a new {@link OXException} instance pre-filled with this code's attributes.
     *
     * @param cause The optional initial cause
     * @param args The message arguments in case of printf-style message
     * @return The newly created {@link OXException} instance
     */
    public OXException create(Throwable cause, Object... args) {
        return OXExceptionFactory.getInstance().create(this, cause, args);
    }
}

==> open-xchange-guard_2.8.0.orig.tar.bz2: open-xchange-guard-2.8.0/com.openexchange.guard.pgpcore.services/src/com/openexchange/guard/pgpcore/services/exceptions/PGPCoreServicesExceptionCodes.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.pgpcore.services.exceptions;

import com.openexchange.exception.Category;
import com.openexchange.exception.DisplayableOXExceptionCode;
import com.openexchange.exception.OXException;
import com.openexchange.exception.OXExceptionFactory;
import com.openexchange.exception.OXExceptionStrings;


/**
 * {@link PGPCoreServicesExceptionCodes}
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.4.2
 */
public enum PGPCoreServicesExceptionCodes implements DisplayableOXExceptionCode {

    RECIPIENT_KEY_NOT_FOUND("Unable to retrieve recipient's key (%1$s)",PGPCoreServicesExceptionMessages.RECIPIENT_KEY_NOT_FOUND, Category.CATEGORY_ERROR, 1),
    SIGNING_KEY_NOT_FOUND("Unable to retrieve signing key (%1$s)", PGPCoreServicesExceptionMessages.SIGNING_KEY_NOT_FOUND, Category.CATEGORY_ERROR, 2),
    ENCRYPTION_ERROR("An PGP encryption error occured: %1$s", PGPCoreServicesExceptionMessages.ENCRYPTION_ERROR, Category.CATEGORY_ERROR,3),
    DECRYPTION_ERROR("An PGP decryption error occured: %1$s", PGPCoreServicesExceptionMessages.DECRYPTION_ERROR, Category.CATEGORY_ERROR,4),
    SIGNING_ERROR("An PGP signing error occured: %1$s", PGPCoreServicesExceptionMessages.SIGNING_ERROR,Category.CATEGORY_ERROR,5),
    SIGNATURE_VERIFICATION_ERROR("An PGP signature verification error occured: %1$s",PGPCoreServicesExceptionMessages.SIGNATURE_VERIFICATION_ERROR, Category.CATEGORY_ERROR,6),
    UNEXPECTED_ERROR("Unexpected error occured: %1$s", PGPCoreServicesExceptionMessages.UNEXPECTED_ERROR, CATEGORY_ERROR,7),
    RECIPIENT_PARSING_ERROR("Unable to parse the given recipient (%1$s)",PGPCoreServicesExceptionMessages.RECIPIENT_PARSING_ERROR,Category.CATEGORY_ERROR,8);

    ;

    private final String message;
    private final String displayMessage;
    private final Category category;
    private final int number;

    private PGPCoreServicesExceptionCodes(String message, Category category, int number) {
        this(message, null, category, number);
    }

    private PGPCoreServicesExceptionCodes(String message, String displayMessage, Category category, int number) {
        this.message = message;
        this.displayMessage = displayMessage != null ? displayMessage : OXExceptionStrings.MESSAGE;
        this.category = category;
        this.number = number;
    }

    @Override
    public String getPrefix() {
        return "GRD-SVS";
    }

    @Override
    public int getNumber() {
        return number;
    }

    @Override
    public String getMessage() {
        return message;
    }

    @Override
    public String getDisplayMessage() {
        return displayMessage;
    }

    @Override
    public Category getCategory() {
        return category;
    }

    @Override
    public boolean equals(OXException e) {
        return OXExceptionFactory.getInstance().equals(this, e);
    }

    /**
     * Creates a new {@link OXException} instance pre-filled with this code's attributes.
     *
     * @return The newly created {@link OXException} instance
     */
    public OXException create() {
        return OXExceptionFactory.getInstance().create(this, new Object[0]);
    }

    /**
     * Creates a new {@link OXException} instance pre-filled with this code's attributes.
     *
     * @param args The message arguments in case of printf-style message
     * @return The newly created {@link OXException} instance
     */
    public OXException create(Object... args) {
        return OXExceptionFactory.getInstance().create(this, (Throwable) null, args);
    }

    /**
     * Creates a new {@link OXException} instance pre-filled with this code's attributes.
     *
     * @param cause The optional initial cause
     * @param args The message arguments in case of printf-style message
     * @return The newly created {@link OXException} instance
     */
    public OXException create(Throwable cause, Object... args) {
        return OXExceptionFactory.getInstance().create(this, cause, args);
    }
}
